@@ -6,7 +6,7 @@ use warnings;
 use experimental 'smartmatch';
 #use Log::Any '$log';
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -88,7 +88,7 @@ sub detect_terminal {
         }
 
         # Windows command prompt
-        if ($ENV{TERM} eq 'dumb') {
+        if ($ENV{TERM} eq 'dumb' && $ENV{windir}) {
             $info->{emulator_software} = 'windows';
             $info->{emulator_engine}   = 'windows';
             $info->{color_depth}       = 16;
@@ -98,6 +98,17 @@ sub detect_terminal {
             last DETECT;
         }
 
+        # run under CGI or something like that
+        if ($ENV{TERM} eq 'dumb') {
+            $info->{emulator_software} = 'dumb';
+            $info->{emulator_engine}   = 'dumb';
+            $info->{color_depth}       = 0;
+            # XXX how to determine unicode support?
+            $info->{default_bgcolor}   = '000000';
+            $info->{box_chars}         = 0;
+            last DETECT;
+        }
+
         require SHARYANTO::Proc::Util;
         if ($^O !~ /Win/) {
             my $ppids = SHARYANTO::Proc::Util::get_parent_processes();
@@ -166,7 +177,7 @@ Term::Detect::Software - Detect terminal (emulator) software and its capabilitie
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
